@@ -32,13 +32,14 @@ except ImportError:
 class open(OpenBase):
     def __init__(self, filename="", flags=[], radare2home=None):
         super(open, self).__init__(filename, flags)
+        self.pipe_read_sleep = 0.001
         self.pending = b''
         if filename.startswith("http://"):
             self._cmd = self._cmd_http
             self.uri = filename + "/cmd"
         elif filename.startswith("ccall://"):
             self._cmd = self._cmd_native
-            self.uri = filename[7:]
+            self.uri = filename[8:]
         elif filename.startswith("tcp://"):
             r = re.match(r"tcp://(\d+\.\d+.\d+.\d+):(\d+)/?", filename)
             if not r:
@@ -59,6 +60,9 @@ class open(OpenBase):
             if os.name == "nt":
                 # avoid errors on Windows when subprocess messes with name
                 r2e += ".exe"
+                hello_cmd = False
+            else:
+                hello_cmd = True
             cmd = [r2e, "-q0", filename]
             cmd = cmd[:1] + flags + cmd[1:]
             try:
@@ -67,7 +71,6 @@ class open(OpenBase):
                 )
             except:
                 raise Exception("ERROR: Cannot find radare2 in PATH")
-            hello_cmd = True
             if hello_cmd:
                 self.process.stdout.read(1)  # Reads initial \x00
                 try:
@@ -128,19 +131,26 @@ class open(OpenBase):
         while True:
             if self.nonblocking:
                 try:
+                    null_start = False
                     if len(self.pending) > 0:
                         foo = self.pending
                         self.pending = b""
                     else:
                         foo = r.read(4096)
-                    if foo is not None:
+                        if os.name == "nt":
+                            if foo.startswith(b"\x00"):
+                                foo = foo[1:]
+                                null_start = True
+                    if foo:
                         zro = foo.find(b"\x00")
                         if zro != -1:
                             out += foo[0:zro]
-                            if zro < len(foo):
+                            if zro  < len(foo):
                                 self.pending = foo[zro + 1:]
                             break
                         out += foo
+                    elif null_start:
+                        break
                 except:
                     pass
             else:
@@ -149,7 +159,7 @@ class open(OpenBase):
                     if foo == b"\x00":
                         break
                     out += foo
-            time.sleep(0.001)
+            time.sleep(self.pipe_read_sleep)
         return out.decode("utf-8", errors="ignore")
 
     def _cmd_http(self, cmd):
